@@ -11,6 +11,8 @@ class Driver(object):
     :param dry_run: True if no writes to the Yahoo APIs
     :param full: True if we are to optimize using the free agents.  False means
         we just optimize for our bench.
+    :param prompt: True if we are to prompt for each roster move.  False means
+        we answer yes for each prompt.
     :param reset_cache: True if the cache files should be removed before running
     """
     def __init__(self, cfg, dry_run, full, prompt, reset_cache):
@@ -30,7 +32,6 @@ class Driver(object):
         if self.full:
             print("Optimizing full lineup using available free agents")
             self.bot.optimize_lineup_from_free_agents()
-            self.bot.pick_bench()
         else:
             print("Optimizing open lineup spots using available free agents")
             self.bot.fill_empty_spots_from_bench()
@@ -38,6 +39,7 @@ class Driver(object):
             print("Optimizing lineup using players available from bench")
             self.bot.pick_bench()
             self.bot.optimize_lineup_from_bench()
+        self.bot.pick_bench()
         print("Optimized lineup")
         self.bot.print_roster()
         print("Computing roster moves to apply")
