@@ -79,7 +79,7 @@ class ScoreComparer:
         :return: Aggregation compuation for each category
         :rtype: DataFrame
         """
-        scores = pd.DataFrame()
+        scores = []
         for lineup in lineups:
             if type(lineup) is pd.DataFrame:
                 df = pd.DataFrame(data=lineup, columns=lineup.columns)
@@ -88,8 +88,9 @@ class ScoreComparer:
             # Lineup could be empty if all players were moved to the bench
             if len(df.index) > 0:
                 score_sum = self.scorer.summarize(df)
-                scores = scores.append(score_sum, ignore_index=True)
-        return scores.agg([agg])
+                scores.append(score_sum)
+        df = pd.DataFrame(scores)
+        return df.agg([agg])
 
 
 class ManagerBot:
@@ -138,9 +139,19 @@ class ManagerBot:
             return bench
 
         # We'll pick the bench spots by picking players not in your lineup or
-        # IR but have the highest ownership %.
+        # IR.  We first pick from locked players then pick the highest
+        # ownership %.
         lineup_names = [e['name'] for e in self.lineup] + \
             [e['name'] for e in self.injury_reserve]
+
+        for plyr_name in self._get_locked_players_list():
+            if plyr_name not in lineup_names:
+                plyr_from_pool = self.ppool[self.ppool['name'] == plyr_name]
+                bench.append(plyr_from_pool.iloc(0)[0])
+                if len(bench) == self.lg_statics.bn_spots:
+                    self.bench = bench
+                    return
+
         top_owners = self.ppool.sort_values(by=["percent_owned"],
                                             ascending=False)
         for plyr in top_owners.iterrows():
@@ -150,8 +161,8 @@ class ManagerBot:
                     p['name'], p['percent_owned']))
                 bench.append(p)
                 if len(bench) == self.lg_statics.bn_spots:
-                    break
-        self.bench = bench
+                    self.bench = bench
+                    return
 
     def pick_injury_reserve(self):
         """Pick the injury reserve slots"""
@@ -162,7 +173,8 @@ class ManagerBot:
         ir = []
         roster = self._get_orig_roster()
         for plyr in roster:
-            if plyr['status'].startswith(self.lg_statics.ir_name):
+            if plyr['status'].startswith(self.lg_statics.ir_name) or \
+                    plyr['status'] == 'COVID-19':
                 ir.append(plyr)
                 for idx, lp in enumerate(self.lineup):
                     if lp['player_id'] == plyr['player_id']:
@@ -377,7 +389,7 @@ class ManagerBot:
         optimizer_func = self._get_lineup_optimizer_function()
         ppool = pd.DataFrame(data=self.bench, columns=self.bench[0].index)
         ldf = pd.DataFrame(data=self.lineup, columns=self.lineup[0].index)
-        ppool = ppool.append(ldf, ignore_index=True, sort=False)
+        ppool = pd.concat([ppool, ldf], ignore_index=True, sort=False)
         ppool = ppool[ppool['status'] == '']
         new_lineup = optimizer_func(self.cfg, self.score_comparer,
                                     self.my_team_bldr, ppool, [])
